@@ -540,6 +540,12 @@ class UBXMessage:
                     self._ubxClass == b"\x01" and self._ubxID == b"\x3C"
                 ):  # NAV-RELPOSNED
                     pdict = self._get_relposned_version(**kwargs)
+                elif self._ubxClass in [
+                    b"\x03",
+                    b"\x08",
+                    b"\x0c",
+                ]:  # u-blox TRK, TUN & DBG msgs
+                    pdict = ubg.UBX_PAYLOADS_GET["UBX-DEBUG"]
                 else:
                     pdict = ubg.UBX_PAYLOADS_GET[self.identity]
             return pdict
@@ -816,6 +822,7 @@ class UBXMessage:
         """
 
         clsid = None
+        msgid = None
 
         umsg_name = self.identity
         if self.payload is None:
@@ -829,22 +836,17 @@ class UBXMessage:
                     val = gnss2str(val)  # get string representation e.g. 'GPS'
                 if att == "iTOW":  # attribute is a GPS Time of Week
                     val = itow2utc(val)  # show time in UTC format
-                # if it's an ACK-ACK or ACK-NAK, we show what it's acknowledging in plain text
-                if self._ubxClass == b"\x05":  # ACK
-                    if att == "clsID":
-                        clsid = val2bytes(val, ubt.U1)
-                        val = ubt.UBX_CLASSES[clsid]
-                    if att == "msgID" and clsid:
-                        msgid = val2bytes(val, ubt.U1)
-                        val = ubt.UBX_MSGIDS[clsid + msgid]
+                # if it's an ACK, we show what it's acknowledging in plain text
                 # if it's a CFG-MSG, we show what message class/id it refers to in plain text
-                if self._ubxClass == b"\x06" and self._ubxID == b"\x01":  # CFG-MSG
-                    if att == "msgClass":
+                if self._ubxClass == b"\x05" or (
+                    self._ubxClass == b"\x06" and self._ubxID == b"\x01"
+                ):
+                    if att in ["clsID", "msgClass"]:
                         clsid = val2bytes(val, ubt.U1)
-                        val = ubt.UBX_CLASSES[clsid]
+                        val = ubt.UBX_CLASSES.get(clsid, clsid)
                     if att == "msgID" and clsid:
                         msgid = val2bytes(val, ubt.U1)
-                        val = ubt.UBX_MSGIDS[clsid + msgid]
+                        val = ubt.UBX_MSGIDS.get(clsid + msgid, clsid + msgid)
                 stg += att + "=" + str(val)
                 if i < len(self.__dict__) - 1:
                     stg += ", "
@@ -917,11 +919,19 @@ class UBXMessage:
                 umsg_name = ubt.UBX_MSGIDS[
                     self._ubxClass + self._ubxID + self._payload[0:1]
                 ]
+            # undocumented u-blox DBG, TRK & TUN messages,
+            # parsed to a nominal UBX-DEBUG definition
+            elif self._ubxClass in [b"\x03", b"\x08", b"\x0c"]:
+                umsg_name = (
+                    f"{ubt.UBX_CLASSES[self._ubxClass]}-"
+                    + f"{int.from_bytes(self._ubxClass, 'little'):02x}"
+                    + f"{int.from_bytes(self._ubxID, 'little'):02x}"
+                )
             else:
                 umsg_name = ubt.UBX_MSGIDS[self._ubxClass + self._ubxID]
         except KeyError as err:
             raise ube.UBXMessageError(
-                f"Unknown UBX message type class {self._ubxClass} id {self._ubxID}"
+                f"Undefined message class {self._ubxClass}, id {self._ubxID}"
             ) from err
         return umsg_name
 
