@@ -209,6 +209,21 @@ UBX_PAYLOADS_GET = {
         "pioId": U1,
         "reserved0": U1,
     },
+    "CFG-CFG": {
+        "clearMask": X4,
+        "saveMask": X4,
+        "loadMask": X4,
+        "deviceMask": (
+            X1,
+            {
+                "devBBR": U1,
+                "devFlash": U1,
+                "devEEPROM": U1,
+                "reserved1": U1,
+                "devSpiFlash": U1,
+            },
+        ),
+    },
     "CFG-DAT": {
         "datumNum": U2,
         "datumName": C6,
@@ -765,6 +780,32 @@ UBX_PAYLOADS_GET = {
         "cogLpGain": U1,
         "reserved3": U2,
     },
+    "CFG-PM": {
+        "version": U1,
+        "reserved1": U1,
+        "reserved2": U1,
+        "reserved3": U1,
+        "flags": (
+            X4,
+            {
+                "reserved4": U2,
+                "interval": U2,
+                "exintSelect": U1,
+                "extintWake": U1,
+                "extintBackup": U1,
+                "reserved5": U1,
+                "limitPeakCurr": U2,
+                "waitTimeFix": U1,
+                "updateRTC": U1,
+                "updateEPH": U1,
+            },
+        ),
+        "updatePeriod": U4,
+        "searchPeriod": U4,
+        "gridOffset": U4,
+        "onTime": U2,
+        "minAcqTime": U2,
+    },
     "CFG-PM2": {
         "version": U1,
         "reserved0": U1,
@@ -1001,6 +1042,15 @@ UBX_PAYLOADS_GET = {
         "sensorId": U2,
         "reserved1": U8,
     },
+    "CFG-TMODE": {
+        "timeMode": U4,
+        "fixedPosX": I4,
+        "fixedPosY": I4,
+        "fixedPosZ": I4,
+        "fixedPosVar": U4,
+        "svinMinDur": U4,
+        "svinVarLimit": U4,
+    },
     "CFG-TMODE2": {
         "timeMode": U1,
         "reserved1": U1,
@@ -1040,6 +1090,22 @@ UBX_PAYLOADS_GET = {
         "svinAccLimit": U4,
         "reserved2": U8,
     },
+    "CFG-TP": {
+        "interval": U4,
+        "length": U4,
+        "status": I1,
+        "timeRef": U1,
+        "flags": (
+            X1,
+            {
+                "syncMode": U1,
+            },
+        ),
+        "reserved0": U1,
+        "antennaCableDelay": I2,
+        "rfGroupDelay": I2,
+        "userDelay": I4,
+    },
     "CFG-TP5": {
         "tpIdx": U1,
         "version": U1,
@@ -3526,6 +3592,16 @@ UBX_PAYLOADS_GET = {
         "reserved1": U3,
     },
     # ********************************************************************
+    # UBX u-center debug message - nominal definition
+    "UBX-DEBUG": {
+        "group": (
+            "None",
+            {
+                "data": X1,
+            },
+        )
+    },
+    # ********************************************************************
     # Dummy message for error testing
     "FOO-BAR": {"spam": "Z2", "eggs": "Y1"},
 }
@@ -3563,6 +3639,11 @@ _UBX_PAYLOADS_GET_NAV2 = {
     "NAV2-TIMEUTC": UBX_PAYLOADS_GET["NAV-TIMEUTC"],
     "NAV2-VELECEF": UBX_PAYLOADS_GET["NAV-VELECEF"],
     "NAV2-VELNED": UBX_PAYLOADS_GET["NAV-VELNED"],
+    # a few other debug message types which reuse nominal definitions...
+    "MON-0a05": UBX_PAYLOADS_GET["UBX-DEBUG"],
+    "MON-0a11": UBX_PAYLOADS_GET["UBX-DEBUG"],
+    "MON-0a26": UBX_PAYLOADS_GET["UBX-DEBUG"],
+    "SEC-2700": UBX_PAYLOADS_GET["UBX-DEBUG"],
 }
 
 # Update main dictionary with NAV2 definitions
